bidding_zones = {
    "NO_1": {
        "cities": ["Oslo", "Kristiansand", "Stavanger", "Bergen"]
    },
    "NO_2": {
        "cities": ["Haugesund", "Sandnes", "Molde"]
    },
    "NO_3": {
        "cities": ["Trondheim", "Steinkjer", "Namsos"]
    },
    "NO_4": {
        "cities": ["Bodø", "Tromsø", "Hammerfest"]
    },
    "NO_5": {
        "cities": ["Sarpsborg", "Fredrikstad", "Drammen"]
    },
    "SE_1": {
        "cities": ["Luleå", "Kiruna", "Gällivare"]
    },
    "SE_2": {
        "cities": ["Sundsvall", "Gävle", "Östersund"]
    },
    "SE_3": {
        "cities": ["Malmö", "Gothenburg", "Helsingborg", "Jönköping"]
    },
    "SE_4": {
        "cities": ["Stockholm", "Uppsala", "Västerås", "Linköping"]
    }
}
